@@ -19,54 +19,41 @@ class Vport(object):
     - ixnetworkapi (IxNetworkApi): instance of the IxNetworkApi class
     """
     _SPEED_MAP = {
-        'one_hundred_gbps': 'speed100g', 
-        'fifty_gbps': 'speed50g', 
-        'forty_gbps': 'speed40g', 
-        'twenty_five_gpbs': 'speed25g', 
-        'ten_gbps': 'speed10g',
-        'one_thousand_mbps': 'speed1000',
-        'one_hundred_fd_mbps': 'speed100fd',
-        'one_hundred_hd_mbps': 'speed100hd',
-        'ten_fd_mbps': 'speed10fd', 
-        'ten_hd_mbps': 'speed10hd'        
+        'speed_100_gbps': 'speed100g',
+        'speed_50_gbps': 'speed50g',
+        'speed_40_gbps': 'speed40g',
+        'speed_25_gbps': 'speed25g',
+        'speed_10_gbps': 'speed10g',
+        'speed_1_gbps': 'speed1000',
+        'speed_100_fd_mbps': 'speed100fd',
+        'speed_100_hd_mbps': 'speed100hd',
+        'speed_10_fd_mbps': 'speed10fd',
+        'speed_10_hd_mbps': 'speed10hd'
     }
     _ADVERTISE_MAP = {
         'advertise_one_thousand_mbps': 'speed1000',
         'advertise_one_hundred_fd_mbps': 'speed100fd',
-        'advertise_one_hundred_hd_mbps': 'speed100hd', 
-        'advertise_ten_fd_mbps': 'speed10fd', 
-        'advertise_ten_hd_mbps': 'speed10hd'        
+        'advertise_one_hundred_hd_mbps': 'speed100hd',
+        'advertise_ten_fd_mbps': 'speed10fd',
+        'advertise_ten_hd_mbps': 'speed10hd'
     }
     _FLOW_CONTROL_MAP = {
         'ieee_802_1qbb': 'ieee802.1Qbb',
         'ieee_802_3x': 'ieee_802_3x'
     }
     _RESULT_COLUMNS = [
-        'name',
-        'location',
-        'link',
-        'capture',
-        'frames_tx',
-        'frames_rx',
-        'frames_tx_rate',
-        'frames_rx_rate',
-        'bytes_tx',
-        'bytes_rx',
-        'bytes_tx_rate',
-        'bytes_rx_rate',
-        'pfc_class_0_frames_rx',
-        'pfc_class_1_frames_rx',
-        'pfc_class_2_frames_rx',
-        'pfc_class_3_frames_rx',
-        'pfc_class_4_frames_rx',
-        'pfc_class_5_frames_rx',
-        'pfc_class_6_frames_rx',
-        'pfc_class_7_frames_rx'            
+        'name', 'location', 'link', 'capture', 'frames_tx', 'frames_rx',
+        'frames_tx_rate', 'frames_rx_rate', 'bytes_tx', 'bytes_rx',
+        'bytes_tx_rate', 'bytes_rx_rate', 'pfc_class_0_frames_rx',
+        'pfc_class_1_frames_rx', 'pfc_class_2_frames_rx',
+        'pfc_class_3_frames_rx', 'pfc_class_4_frames_rx',
+        'pfc_class_5_frames_rx', 'pfc_class_6_frames_rx',
+        'pfc_class_7_frames_rx'
     ]
 
     def __init__(self, ixnetworkapi):
         self._api = ixnetworkapi
-        
+
     def config(self):
         """Transform config.ports into Ixnetwork.Vport
         1) delete any vport that is not part of the config
@@ -92,7 +79,7 @@ class Vport(object):
         """Delete any vports from the api server that do not exist in the new config
         """
         self._api._remove(self._ixn_vport, self._api.config.ports)
-    
+
     def _create_vports(self):
         """Add any vports to the api server that do not already exist
         """
@@ -101,16 +88,16 @@ class Vport(object):
         for port in self._api.config.ports:
             if port.name not in vports.keys():
                 index = len(vports) + len(imports) + 1
-                imports.append(
-                    {
-                        'xpath': '/vport[%i]' % index,
-                        'name': port.name,
-                        'rxMode': 'captureAndMeasure',
-                        'txMode': 'interleaved'
-                    }
-                )
+                imports.append({
+                    'xpath': '/vport[%i]' % index,
+                    'name': port.name,
+                    'rxMode': 'captureAndMeasure',
+                    'txMode': 'interleaved'
+                })
         self._import(imports)
-    
+        for name, vport in self._api.select_vports().items():
+            self._api.ixn_objects[name] = vport['href']
+
     def _create_capture(self):
         """Overwrite any capture settings
         """
@@ -134,15 +121,9 @@ class Vport(object):
                     'hardwareEnabled': False,
                     'softwareEnabled': False
                 }
-                pallette = {
-                    'xpath': capture['xpath'] + '/filterPallette'
-                }
-                filter = {
-                    'xpath': capture['xpath'] + '/filter'
-                }
-                trigger = {
-                    'xpath': capture['xpath'] + '/trigger'
-                }
+                pallette = {'xpath': capture['xpath'] + '/filterPallette'}
+                filter = {'xpath': capture['xpath'] + '/filter'}
+                trigger = {'xpath': capture['xpath'] + '/trigger'}
                 if capture_item.basic is not None:
                     capture['hardwareEnabled'] = True
                     filter['captureFilterEnable'] = True
@@ -152,19 +133,25 @@ class Vport(object):
                         if basic.choice == 'mac_address' and basic.mac_address.mac == 'source':
                             pallette['SA1'] = basic.mac_address.filter
                             pallette['SAMask1'] = basic.mac_address.mask
-                            filter['captureFilterSA'] = 'notAddr1' if basic.not_operator is True else 'addr1'
-                            trigger['triggerFilterSA'] = filter['captureFilterSA']
+                            filter[
+                                'captureFilterSA'] = 'notAddr1' if basic.not_operator is True else 'addr1'
+                            trigger['triggerFilterSA'] = filter[
+                                'captureFilterSA']
                         elif basic.choice == 'mac_address' and basic.mac_address.mac == 'destination':
                             pallette['DA1'] = basic.mac_address.filter
                             pallette['DAMask1'] = basic.mac_address.mask
-                            filter['captureFilterDA'] = 'notAddr1' if basic.not_operator is True else 'addr1'
-                            trigger['triggerFilterDA'] = filter['captureFilterDA']
+                            filter[
+                                'captureFilterDA'] = 'notAddr1' if basic.not_operator is True else 'addr1'
+                            trigger['triggerFilterDA'] = filter[
+                                'captureFilterDA']
                         elif basic.choice == 'custom':
                             pallette['pattern1'] = basic.custom.filter
                             pallette['patternMask1'] = basic.custom.mask
                             pallette['patternOffset1'] = basic.custom.offset
-                            filter['captureFilterPattern'] = 'notPattern1' if basic.not_operator is True else 'pattern1'
-                            trigger['triggerFilterPattern'] = filter['captureFilterPattern']
+                            filter[
+                                'captureFilterPattern'] = 'notPattern1' if basic.not_operator is True else 'pattern1'
+                            trigger['triggerFilterPattern'] = filter[
+                                'captureFilterPattern']
                 imports.append(capture)
                 imports.append(pallette)
                 imports.append(filter)
@@ -183,16 +170,20 @@ class Vport(object):
         ip_addresses = set(ip_addresses)
         if len(ip_addresses) == 0:
             return
-        self._api._ixnetwork.info('Adding location hosts [%s]...' % ', '.join(ip_addresses))
+        self._api._ixnetwork.info('Adding location hosts [%s]...' %
+                                  ', '.join(ip_addresses))
         for ip_address in ip_addresses:
             chassis.add(Hostname=ip_address)
         start_time = time.time()
         while True:
-            chassis.find(Hostname='^(%s)$' % '|'.join(ip_addresses), State='^ready$')
+            chassis.find(Hostname='^(%s)$' % '|'.join(ip_addresses),
+                         State='^ready$')
             if len(chassis) == len(ip_addresses):
                 break
             if time.time() - start_time > HostReadyTimeout:
-                raise RuntimeError('After %s seconds, not all location hosts [%s] are reachable' % (HostReadyTimeout, ', '.join(ip_addresses)))
+                raise RuntimeError(
+                    'After %s seconds, not all location hosts [%s] are reachable'
+                    % (HostReadyTimeout, ', '.join(ip_addresses)))
             time.sleep(2)
 
     def _set_location(self):
@@ -201,26 +192,32 @@ class Vport(object):
         vports = self._api.select_vports()
         imports = []
         for port in self._api.config.ports:
-            self._api.ixn_objects[port.name] = vports[port.name]['href']
+            vport = vports[port.name]
             location = getattr(port, 'location', None)
-            vport = {
-                'xpath': vports[port.name]['xpath'],
-                'location': location
-            }
+            if vport['location'] == location and vport[
+                    'connectionState'].startswith('connectedLink'):
+                continue
+            self._api.ixn_objects[port.name] = vport['href']
+            vport = {'xpath': vports[port.name]['xpath'], 'location': location}
             imports.append(vport)
             if location is not None and len(location) > 0:
                 locations.append(port.name)
-        self._api._ixnetwork.info('Connecting locations [%s]...' % ', '.join(locations))
+        self._api._ixnetwork.info('Connecting locations [%s]...' %
+                                  ', '.join(locations))
         self._import(imports)
-        self._api._ixnetwork.info('Checking location state [%s]...' % ', '.join(locations))
+        self._api._ixnetwork.info('Checking location state [%s]...' %
+                                  ', '.join(locations))
         start = time.time()
         timeout = 30
         while True:
-            self._api._vport.find(Name='^(%s)$' % '|'.join(locations), ConnectionState='^connectedLink')
+            self._api._vport.find(Name='^(%s)$' % '|'.join(locations),
+                                  ConnectionState='^connectedLink')
             if len(self._api._vport) == len(locations):
                 break
             if time.time() - start > timeout:
-                raise RuntimeError('After %s seconds, not all locations [%s] are reachable' % (timeout, ', '.join(locations)))
+                raise RuntimeError(
+                    'After %s seconds, not all locations [%s] are reachable' %
+                    (timeout, ', '.join(locations)))
             time.sleep(2)
 
     def _set_layer1(self):
@@ -236,20 +233,26 @@ class Vport(object):
         for layer1 in self._api.config.layer1:
             for port_name in layer1.port_names:
                 vport = vports[port_name]
-                if vport['connectionState'] in ['connectedLinkUp', 'connectedLinkDown']:
-                    if layer1.choice == 'ethernet':
+                if vport['connectionState'] in [
+                        'connectedLinkUp', 'connectedLinkDown'
+                ]:
+                    if layer1.speed in [
+                            'speed_10_mbps', 'speed_100_mbps', 'speed_1_gbps'
+                    ]:
                         self._configure_ethernet(vport, layer1, imports)
-                    elif layer1.choice == 'one_hundred_gbe':
-                        reset_auto_negotiation[port_name] = layer1.one_hundred_gbe.auto_negotiate is not None
+                    else:
+                        reset_auto_negotiation[
+                            port_name] = layer1.auto_negotiate
                         self._configure_100gbe(vport, layer1, imports)
         self._import(imports)
-        
+
         # Due to dependency attribute (ieeeL1Defaults) resetting enableAutoNegotiation
         imports = []
         for layer1 in self._api.config.layer1:
             for port_name in layer1.port_names:
                 vport = vports[port_name]
-                if port_name in reset_auto_negotiation and reset_auto_negotiation[port_name]:
+                if port_name in reset_auto_negotiation and reset_auto_negotiation[
+                        port_name]:
                     self._reset_auto_negotiation(vport, layer1, imports)
         self._import(imports)
 
@@ -263,87 +266,108 @@ class Vport(object):
         be switched to a type without the Fcoe extension.
         """
         fcoe = False
-        if hasattr(interface, 'flow_control') and interface.flow_control is not None:
+        if hasattr(interface,
+                   'flow_control') and interface.flow_control is not None:
             fcoe = True
         vport_type = vport['type']
         elegible_fcoe_vport_types = [
-            'ethernet', 'tenGigLan', 'fortyGigLan', 'tenGigWan', 'hundredGigLan',
-            'tenFortyHundredGigLan', 'novusHundredGigLan', 'novusTenGigLan',
-            'krakenFourHundredGigLan', 'aresOneHundredGigLan'
+            'ethernet', 'tenGigLan', 'fortyGigLan', 'tenGigWan',
+            'hundredGigLan', 'tenFortyHundredGigLan', 'novusHundredGigLan',
+            'novusTenGigLan', 'krakenFourHundredGigLan', 'aresOneHundredGigLan'
         ]
         if fcoe is True and vport_type in elegible_fcoe_vport_types:
             vport_type = vport_type + 'Fcoe'
         if fcoe is False and vport_type.endswith('Fcoe'):
             vport_type = vport_type.replace('Fcoe', '')
         if vport_type != vport['type']:
-            imports.append(
-                {
-                    'xpath': vport['xpath'],
-                    'type': vport_type
-                }
-            )
+            imports.append({'xpath': vport['xpath'], 'type': vport_type})
         if fcoe is True and vport_type.endswith('Fcoe'):
             self._configure_fcoe(vport, interface.flow_control, imports)
         return vport_type
 
     def _configure_ethernet(self, vport, layer1, imports):
-        if hasattr(layer1, 'ethernet') is True and layer1.ethernet is not None:
-            self._configure_layer1_type(layer1.ethernet, vport, imports)
-            ethernet = layer1.ethernet
-            advertise = []
-            if ethernet.advertise_one_thousand_mbps is True:
-                advertise.append(Vport._ADVERTISE_MAP['advertise_one_thousand_mbps'])
-            if ethernet.advertise_one_hundred_fd_mbps is True:
-                advertise.append(Vport._ADVERTISE_MAP['advertise_one_hundred_fd_mbps'])
-            if ethernet.advertise_one_hundred_hd_mbps is True:
-                advertise.append(Vport._ADVERTISE_MAP['advertise_one_hundred_hd_mbps'])
-            if ethernet.advertise_ten_fd_mbps is True:
-                advertise.append(Vport._ADVERTISE_MAP['advertise_ten_fd_mbps'])
-            if ethernet.advertise_ten_hd_mbps is True:
-                advertise.append(Vport._ADVERTISE_MAP['advertise_ten_hd_mbps'])
-            imports.append(
-                {
-                    'xpath': vport['xpath'] + '/l1Config/' + vport['type'].replace('Fcoe', ''),
-                    'speed': Vport._SPEED_MAP[ethernet.speed],
-                    'media': ethernet.media,
-                    'autoNegotiate': ethernet.auto_negotiate,
-                    'speedAuto': advertise
-                }
-            )
+        self._configure_layer1_type(layer1, vport, imports)
+        ethernet = layer1.auto_negotiation
+        advertise = []
+        if layer1.speed == 'speed_1_gbps':
+            advertise.append(
+                Vport._ADVERTISE_MAP['advertise_one_thousand_mbps'])
+        if layer1.speed == 'speed_100_fd_mbps':
+            advertise.append(
+                Vport._ADVERTISE_MAP['advertise_one_hundred_fd_mbps'])
+        if layer1.speed == 'speed_100_hd_mbps':
+            advertise.append(
+                Vport._ADVERTISE_MAP['advertise_one_hundred_hd_mbps'])
+        if layer1.speed == 'speed_10_fd_mbps':
+            advertise.append(Vport._ADVERTISE_MAP['advertise_ten_fd_mbps'])
+        if layer1.speed == 'speed_10_hd_mbps':
+            advertise.append(Vport._ADVERTISE_MAP['advertise_ten_hd_mbps'])
+        ethernet_import = {
+            'xpath':
+            vport['xpath'] + '/l1Config/' + vport['type'].replace('Fcoe', ''),
+            'speed':
+            Vport._SPEED_MAP[layer1.speed],
+            'media':
+            layer1.media,
+            'autoNegotiate':
+            layer1.auto_negotiate,
+            'speedAuto':
+            advertise
+        }
+        if self._set_l1config_ethernet(vport, ethernet_import) is True:
+            imports.append(ethernet_import)
+    
+    def _set_l1config_ethernet(self, vport, ethernet):
+        if vport['type'] != 'ethernet':
+            return True
+        for name in ['speed', 'media', 'autoNegotiate', 'speedAuto']:
+            if ethernet[name] == None:
+                continue
+            if ethernet[name] != vport['l1Config']['ethernet'][name]:
+                return True
+        return False
 
     def _configure_100gbe(self, vport, layer1, imports):
-        if hasattr(layer1, 'one_hundred_gbe') is True and layer1.one_hundred_gbe is not None:
-            self._configure_layer1_type(layer1.one_hundred_gbe, vport, imports)
-            one_hundred_gbe = layer1.one_hundred_gbe
-            imports.append(
-                {
-                    'xpath': vport['xpath'] + '/l1Config/' + vport['type'].replace('Fcoe', ''),
-                    'ieeeL1Defaults': one_hundred_gbe.ieee_media_defaults,
-                    'speed': Vport._SPEED_MAP[one_hundred_gbe.speed],
-                    'enableAutoNegotiation': one_hundred_gbe.auto_negotiate,
-                    'enableRsFec': one_hundred_gbe.rs_fec,
-                    'linkTraining': one_hundred_gbe.link_training,
-                }
-            )
-    
+        self._configure_layer1_type(layer1, vport, imports)
+        imports.append({
+            'xpath':
+            vport['xpath'] + '/l1Config/' + vport['type'].replace('Fcoe', ''),
+            'ieeeL1Defaults':
+            layer1.ieee_media_defaults,
+            'speed':
+            Vport._SPEED_MAP[layer1.speed],
+            'enableAutoNegotiation':
+            layer1.auto_negotiate,
+            'enableRsFec':
+            layer1.auto_negotiation.rs_fec,
+            'linkTraining':
+            layer1.auto_negotiation.link_training,
+        })
+
     def _reset_auto_negotiation(self, vport, layer1, imports):
-        if hasattr(layer1, 'one_hundred_gbe') is True and layer1.one_hundred_gbe is not None:
+        if hasattr(layer1, 'one_hundred_gbe'
+                   ) is True and layer1.one_hundred_gbe is not None:
             one_hundred_gbe = layer1.one_hundred_gbe
-            imports.append(
-                {
-                    'xpath': vport['xpath'] + '/l1Config/' + vport['type'].replace('Fcoe', ''),
-                    'enableAutoNegotiation': one_hundred_gbe.auto_negotiate,
-                }
-            )
+            imports.append({
+                'xpath':
+                vport['xpath'] + '/l1Config/' +
+                vport['type'].replace('Fcoe', ''),
+                'enableAutoNegotiation':
+                one_hundred_gbe.auto_negotiate,
+            })
 
     def _configure_fcoe(self, vport, flow_control, imports):
         if flow_control is not None and flow_control.choice == 'ieee_802_1qbb':
             pfc = flow_control.ieee_802_1qbb
             fcoe = {
-                'xpath': vport['xpath'] + '/l1Config/' + vport['type'] + '/fcoe',
-                'enablePFCPauseDelay': True,
-                'flowControlType': Vport._FLOW_CONTROL_MAP[flow_control.choice],
-                'pfcPauseDelay': pfc.pfc_delay,
+                'xpath':
+                vport['xpath'] + '/l1Config/' + vport['type'] + '/fcoe',
+                'enablePFCPauseDelay':
+                True,
+                'flowControlType':
+                Vport._FLOW_CONTROL_MAP[flow_control.choice],
+                'pfcPauseDelay':
+                pfc.pfc_delay,
                 'pfcPriorityGroups': [
                     -1 if pfc.pfc_class_0 is None else pfc.pfc_class_0,
                     -1 if pfc.pfc_class_1 is None else pfc.pfc_class_1,
@@ -354,8 +378,10 @@ class Vport(object):
                     -1 if pfc.pfc_class_6 is None else pfc.pfc_class_6,
                     -1 if pfc.pfc_class_7 is None else pfc.pfc_class_7,
                 ],
-                'priorityGroupSize': 'priorityGroupSize-8',
-                'supportDataCenterMode': True
+                'priorityGroupSize':
+                'priorityGroupSize-8',
+                'supportDataCenterMode':
+                True
             }
             imports.append(fcoe)
 
@@ -370,8 +396,13 @@ class Vport(object):
         except Exception as e:
             self._api.add_error(e)
 
-    def _set_result_value(self, row, column_name, column_value, column_type = str):
-        if len(self._column_names) > 0 and column_name not in self._column_names:
+    def _set_result_value(self,
+                          row,
+                          column_name,
+                          column_value,
+                          column_type=str):
+        if len(self._column_names
+               ) > 0 and column_name not in self._column_names:
             return
         try:
             row[column_name] = column_type(column_value)
@@ -400,29 +431,55 @@ class Vport(object):
             else:
                 location = vport['connectionState']
             self._set_result_value(port_row, 'location', location)
-            self._set_result_value(port_row, 'link', 'up' if vport['connectionState'] == 'connectedLinkUp' else 'down')
+            self._set_result_value(
+                port_row, 'link', 'up'
+                if vport['connectionState'] == 'connectedLinkUp' else 'down')
             self._set_result_value(port_row, 'capture', 'stopped')
             port_rows[vport['name']] = port_row
         try:
             table = self._api.assistant.StatViewAssistant('Port Statistics')
             for row in table.Rows:
                 port_row = port_rows[row['Port Name']]
-                self._set_result_value(port_row, 'frames_tx', row['Frames Tx.'], int)
-                self._set_result_value(port_row, 'frames_rx', row['Valid Frames Rx.'], int)
-                self._set_result_value(port_row, 'frames_tx_rate', row['Frames Tx. Rate'], float)
-                self._set_result_value(port_row, 'frames_rx_rate', row['Valid Frames Rx. Rate'], float)
-                self._set_result_value(port_row, 'bytes_tx', row['Bytes Tx.'], int)
-                self._set_result_value(port_row, 'bytes_rx', row['Bytes Rx.'], int)
-                self._set_result_value(port_row, 'bytes_tx_rate', row['Bytes Tx. Rate'], float)
-                self._set_result_value(port_row, 'bytes_rx_rate', row['Bytes Rx. Rate'], float)
-                self._set_result_value(port_row, 'pfc_class_0_frames_rx', row['Rx Pause Priority Group 0 Frames'], int)
-                self._set_result_value(port_row, 'pfc_class_1_frames_rx', row['Rx Pause Priority Group 1 Frames'], int)
-                self._set_result_value(port_row, 'pfc_class_2_frames_rx', row['Rx Pause Priority Group 2 Frames'], int)
-                self._set_result_value(port_row, 'pfc_class_3_frames_rx', row['Rx Pause Priority Group 3 Frames'], int)
-                self._set_result_value(port_row, 'pfc_class_4_frames_rx', row['Rx Pause Priority Group 4 Frames'], int)
-                self._set_result_value(port_row, 'pfc_class_5_frames_rx', row['Rx Pause Priority Group 5 Frames'], int)
-                self._set_result_value(port_row, 'pfc_class_6_frames_rx', row['Rx Pause Priority Group 6 Frames'], int)
-                self._set_result_value(port_row, 'pfc_class_7_frames_rx', row['Rx Pause Priority Group 7 Frames'], int)
+                self._set_result_value(port_row, 'frames_tx',
+                                       row['Frames Tx.'], int)
+                self._set_result_value(port_row, 'frames_rx',
+                                       row['Valid Frames Rx.'], int)
+                self._set_result_value(port_row, 'frames_tx_rate',
+                                       row['Frames Tx. Rate'], float)
+                self._set_result_value(port_row, 'frames_rx_rate',
+                                       row['Valid Frames Rx. Rate'], float)
+                self._set_result_value(port_row, 'bytes_tx', row['Bytes Tx.'],
+                                       int)
+                self._set_result_value(port_row, 'bytes_rx', row['Bytes Rx.'],
+                                       int)
+                self._set_result_value(port_row, 'bytes_tx_rate',
+                                       row['Bytes Tx. Rate'], float)
+                self._set_result_value(port_row, 'bytes_rx_rate',
+                                       row['Bytes Rx. Rate'], float)
+                self._set_result_value(port_row, 'pfc_class_0_frames_rx',
+                                       row['Rx Pause Priority Group 0 Frames'],
+                                       int)
+                self._set_result_value(port_row, 'pfc_class_1_frames_rx',
+                                       row['Rx Pause Priority Group 1 Frames'],
+                                       int)
+                self._set_result_value(port_row, 'pfc_class_2_frames_rx',
+                                       row['Rx Pause Priority Group 2 Frames'],
+                                       int)
+                self._set_result_value(port_row, 'pfc_class_3_frames_rx',
+                                       row['Rx Pause Priority Group 3 Frames'],
+                                       int)
+                self._set_result_value(port_row, 'pfc_class_4_frames_rx',
+                                       row['Rx Pause Priority Group 4 Frames'],
+                                       int)
+                self._set_result_value(port_row, 'pfc_class_5_frames_rx',
+                                       row['Rx Pause Priority Group 5 Frames'],
+                                       int)
+                self._set_result_value(port_row, 'pfc_class_6_frames_rx',
+                                       row['Rx Pause Priority Group 6 Frames'],
+                                       int)
+                self._set_result_value(port_row, 'pfc_class_7_frames_rx',
+                                       row['Rx Pause Priority Group 7 Frames'],
+                                       int)
         except:
             pass
         return port_rows.values()
